"""
作者：顾平安
联系方式：g332920287@foxmail.com

仅供技术研究使用，请勿商用或者非法用途，如有影响贵司或组织的权益，请联系我删除
"""
from .cli import execute
from .service import create_book, get_content

__all__ = ['execute', 'create_book', 'get_content']


